@@ -2,7 +2,7 @@ import json
 import uuid
 import re
 
-from .__stage__ import Stage, __USER_TEXT__, __SYS_REPLY__, StageStatus, SwitchStage, \
+from .__stage__ import Stage, __USER_TEXT__, __SYS_REPLY__, StageStatus, \
     __LOCAL_VAR_LABEL__, __LOCAL_VAR_VALUE__, StageType, __PASS_TOKEN__, __KEEP_VAR__, \
     __KEEP_DEFAULT_VAR__
 
@@ -98,7 +98,6 @@ class MultiAgent(Agent):
             ##
 
             if self.is_switch_stage(stage) is True:
-                stage: SwitchStage
                 new_stages_label = stage.find_new_stages(kwargs)
                 return self.multi_stages[new_stages_label], kwargs
             else:
